#
# spec file for package euca2ools
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           euca2ools
Version:        2.1.3
Release:        6.1
Summary:        Elastic Utility Computing Architecture Command Line Tools
License:        BSD-2-Clause
Group:          Productivity/Networking/System
Url:            http://open.eucalyptus.com/downloads
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  help2man
BuildRequires:  make
BuildRequires:  python-boto   >= 2.1
BuildRequires:  python-devel
BuildRequires:  python-m2crypto
BuildRequires:  python-xml
Requires:       python-base  >= 2.6
Requires:       python-boto  >= 2.6
Requires:       python-m2crypto
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{?suse_version: %{suse_version} > 1110} %{!?suse_version:1}
BuildArch:      noarch
%else
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(True)")}
%endif

%description
Euca2ools are command-line tools for interacting with Web services that
export a REST/Query-based API compatible with Amazon EC2 and S3 services.
The tools can be used with both Amazon's services and with installations
of the Eucalyptus open-source cloud-computing infrastructure.

%prep
%setup -q

%build
%{__python} setup.py build
sh -xe generate-manpages.sh

%install
%{__python} setup.py install --prefix=%{_prefix} --skip-build --root %{buildroot}
%{__python} setup.py install -O1 --prefix=%{_prefix} --skip-build --root %{buildroot}
find "%{buildroot}%{python_sitelib}/" -name '*.pyo' -exec %__rm {} \;
find "%{buildroot}%{python_sitelib}/" -name '*.pyc' \
    -exec %__rm {} \;
%__python -c 'import compileall;
compileall.compile_dir("%{buildroot}%{python_sitelib}/",
ddir="%{python_sitelib}/",
force=1)'
export DESTDIR=%{buildroot}
export PREFIX=%{_prefix}
sh -xe install-manpages.sh

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc COPYING README
%doc %{_mandir}/man1/*
%{_bindir}/euca*
%{_bindir}/euare*
%{_bindir}/eustore-*
%{python_sitelib}/euca2ools*

%changelog
* Sat Jun  8 2013 rschweikert@suse.com
- update to 2.1.3
  + Fix GetConsoleOutput crash when we get no output
  + Pass DelegateAccount from ListUserPolicies to GetUserPolicy
    (Fixes TOOLS-281)
  + Ensure files identified as kernel or ramdisk don't get re-registered
    as image (Fixes TOOLS-184)
  + Switched to look at account alias (Fixes TOOLS-282)
  + Implement DescribeInstanceAttribute (Fixes TOOLS-102)
  + Make usercreatepolicy pass DelegateAccount (Fixes TOOLS-274)
  + Make sdist grab version info from git if possible
  + Behave more intuitively when both -s and -b are supplied to euca-register
    (Fixes TOOLS-182)
  + Fix query parameter quoting
  + Implement EUCA2-RSA-SHA256 signature (Fixes TOOLS-111)
  + Don't print anything from euca-reboot-instances (Fixes TOOLS-171)
  + Print previous, current states when starting (Fixes TOOLS-175, TOOLS-176)
  + Print previous, current states when terminating (Fixes TOOLS-109)
  + Make --addressing an extension, not deprecated (Fixes TOOLS-169)
  + Make euca-describe-images show image tags
  + Make euca-describe-snapshots show snapshot tags
  + Make euca-describe-volumes show volume tags
  + Make euca-describe-instances show instance tags (Fixes TOOLS-152)
  + No longer try removing tgz since parent (temp) dir is being removed
    (Fixes TOOLS-155)
  + Remove temp directory tree upon completion of image registration
    (Fixes TOOLS-155)
  + Only warn if no kernel/ramdisk were specified (Fixes TOOLS-159)
  + Make BundleInstance require an instance ID (Fixes TOOLS-157)
  + Escape GetConsoleOutput control codes by default (Fixes TOOLS-156)
  + Use id instead of name, and set API version # for boto (Fixes TOOLS-153)
  + Added 'hypervisors-supported' to standard output of eustore-describe-images
  + Add support for --instance-initiated-shutdown-behavior
  + Add DelegateAccount to euare-(group|user)addpolicy (Fixes TOOLS-138)
  + Downgrade >10G image errors to warnings (Fixes TOOLS-145)
  + Fix euare-userenablemfadevice copypaste error (Fixes TOOLS-144)
* Tue Oct 23 2012 mrdocs@opensuse.org
- drop obosolete patches now upstream
- no upstream changelog provided See:
  https://github.com/eucalyptus/euca2ools/commits/master
* Mon Sep 24 2012 bwiedemann@suse.com
- update to 2.1.1
* Fri Apr 13 2012 rschweikert@suse.com
- update to version 2.0.1
  unfortunately upstream does not provide release notes or
  change information past the 1.3.1 release
* Thu Jan  5 2012 rschweikert@suse.com
- force rebuild of pyc files to avoid rpmlint error about
  $BUILDROOT traces in byte code
* Thu Jan  5 2012 rschweikert@suse.com
- add lint filter for naming policy
- include the pyc file in the package
* Fri Dec  9 2011 rschweikert@suse.com
- fix license identifier string
* Thu Dec  9 2010 rschweikert@novell.com
- patch for using boto 2.0
* Tue Nov 16 2010 rschweikert@novell.com
- Add requirements for python-boto and python-m2crypto
* Tue Nov  9 2010 alexandre@exatati.com.br
- Fixed boto s3 connection import.
* Tue Nov  2 2010 alexandre@exatati.com.br
- Redefined python macros to build on SLE.
* Mon Nov  1 2010 alexandre@exatati.com.br
- Building as noarch for openSUSE >= 11.2.
* Mon Nov  1 2010 alexandre@exatati.com.br
- Minor updates on spec file.
* Wed Oct 27 2010 rschweikert@novell.com
- Initial build version 1.3.1
